@@ -8,6 +8,8 @@
 #include <QQuickTextDocument>
 #include <QTextCursor>
 
+#include "models/messagecontentmodel.h"
+
 class ChatDocumentHandler;
 
 namespace Quotient
@@ -33,7 +35,7 @@ struct Mention {
  * A class to cache data from a chat bar.
  *
  * A chat bar can be anything that allows users to compose or edit message, it doesn't
- * necessarily have to use the ChatBar component, e.g. MessageEditComponent.
+ * necessarily have to use the ChatBar component, e.g. ChatBarComponent.
  *
  * This object is intended to allow the current contents of a chat bar to be cached
  * between different rooms, i.e. there is an expectation that each NeoChatRoom could
@@ -43,7 +45,7 @@ struct Mention {
  *       as it's parent. This is necessary for certain functions which need to get
  *       relevant room information.
  *
- * @sa ChatBar, MessageEditComponent, NeoChatRoom
+ * @sa ChatBar, ChatBarComponent, NeoChatRoom
  */
 class ChatBarCache : public QObject
 {
@@ -100,7 +102,7 @@ class ChatBarCache : public QObject
      *
      * @sa Quotient::RoomMember
      */
-    Q_PROPERTY(Quotient::RoomMember relationUser READ relationUser NOTIFY relationIdChanged)
+    Q_PROPERTY(Quotient::RoomMember relationAuthor READ relationAuthor NOTIFY relationIdChanged)
 
     /**
      * @brief The content of the related message.
@@ -109,6 +111,13 @@ class ChatBarCache : public QObject
      */
     Q_PROPERTY(QString relationMessage READ relationMessage NOTIFY relationIdChanged)
 
+    /**
+     * @brief The MessageContentModel for the related message.
+     *
+     * Will be nullptr if no related message.
+     */
+    Q_PROPERTY(MessageContentModel *relationEventContentModel READ relationEventContentModel NOTIFY relationIdChanged)
+
     /**
      * @brief Whether the chat bar is replying in a thread.
      */
@@ -144,6 +153,7 @@ public:
     explicit ChatBarCache(QObject *parent = nullptr);
 
     QString text() const;
+    QString sendText() const;
     void setText(const QString &text);
 
     bool isReplying() const;
@@ -154,9 +164,10 @@ public:
     QString editId() const;
     void setEditId(const QString &editId);
 
-    Quotient::RoomMember relationUser() const;
+    Quotient::RoomMember relationAuthor() const;
 
     QString relationMessage() const;
+    MessageContentModel *relationEventContentModel();
 
     bool isThreaded() const;
     QString threadId() const;
@@ -165,6 +176,13 @@ public:
     QString attachmentPath() const;
     void setAttachmentPath(const QString &attachmentPath);
 
+    /**
+     * @brief Clear all relations in the cache.
+     *
+     * This includes relation ID, thread root ID and attachment path.
+     */
+    Q_INVOKABLE void clearRelations();
+
     /**
      * @brief Retrieve the mentions for the current chat bar text.
      */
@@ -185,18 +203,29 @@ public:
      */
     void setSavedText(const QString &savedText);
 
+    /**
+     * @brief Post the contents of the cache as a message in the room.
+     */
+    Q_INVOKABLE void postMessage();
+
 Q_SIGNALS:
     void textChanged();
     void relationIdChanged(const QString &oldEventId, const QString &newEventId);
-    void threadIdChanged();
+    void threadIdChanged(const QString &oldThreadId, const QString &newThreadId);
     void attachmentPathChanged();
 
 private:
     QString m_text = QString();
+    QString formatMentions() const;
+
     QString m_relationId = QString();
     RelationType m_relationType = RelationType::None;
     QString m_threadId = QString();
     QString m_attachmentPath = QString();
     QList<Mention> m_mentions;
     QString m_savedText;
+
+    QPointer<MessageContentModel> m_relationContentModel;
+
+    void clearCache();
 };
