@@ -8,7 +8,6 @@
 
 ColorSchemer::ColorSchemer(QObject *parent)
     : QObject(parent)
-    , c(new KColorSchemeManager(this))
 {
 }
 
@@ -18,17 +17,17 @@ ColorSchemer::~ColorSchemer()
 
 QAbstractItemModel *ColorSchemer::model() const
 {
-    return c->model();
+    return KColorSchemeManager::instance()->model();
 }
 
 void ColorSchemer::apply(int idx)
 {
-    c->activateScheme(c->model()->index(idx, 0));
+    KColorSchemeManager::instance()->activateScheme(KColorSchemeManager::instance()->model()->index(idx, 0));
 }
 
 int ColorSchemer::indexForCurrentScheme()
 {
-    return c->indexForSchemeId(c->activeSchemeId()).row();
+    return KColorSchemeManager::instance()->indexForSchemeId(KColorSchemeManager::instance()->activeSchemeId()).row();
 }
 
 #include "moc_colorschemer.cpp"
