@@ -37,14 +37,6 @@ class NeoChatRoom;
 class EventHandler
 {
 public:
-    /**
-     * @brief Return the ID of the event.
-     *
-     * Returns the transaction ID if the Matrix ID is empty, which may be the case
-     * for a pending event.
-     */
-    static QString id(const Quotient::RoomEvent *event);
-
     /**
      * @brief Get the display name of the event author.
      *
@@ -72,7 +64,7 @@ public:
     /**
      * @brief Return a QDateTime object for the event timestamp.
      */
-    static QDateTime time(const Quotient::RoomEvent *event, bool isPending = false, QDateTime lastUpdated = {});
+    static QDateTime time(const NeoChatRoom *room, const Quotient::RoomEvent *event, bool isPending = false);
 
     /**
      * @brief Return a QString for the event timestamp.
@@ -88,11 +80,11 @@ public:
      * @param lastUpdated the time the event was last updated locally as this cannot be
      *                    obtained from the event.
      */
-    static QString timeString(const Quotient::RoomEvent *event,
+    static QString timeString(const NeoChatRoom *room,
+                              const Quotient::RoomEvent *event,
                               bool relative,
                               QLocale::FormatType format = QLocale::ShortFormat,
-                              bool isPending = false,
-                              QDateTime lastUpdated = {});
+                              bool isPending = false);
 
     /**
      * @brief Return a QString for the event timestamp.
@@ -106,7 +98,7 @@ public:
      * @param lastUpdated the time the event was last updated locally as this cannot be
      *                    obtained from the event.
      */
-    static QString timeString(const Quotient::RoomEvent *event, const QString &format, bool isPending = false, const QDateTime &lastUpdated = {});
+    static QString timeString(const NeoChatRoom *room, const Quotient::RoomEvent *event, const QString &format, bool isPending = false);
 
     /**
      * @brief Whether the event should be highlighted in the timeline.
@@ -220,20 +212,6 @@ public:
      */
     static QVariantMap mediaInfo(const NeoChatRoom *room, const Quotient::RoomEvent *event);
 
-    /**
-     * @brief Whether the event is a reply to another in the timeline.
-     *
-     * @param showFallbacks whether message that have is_falling_back set true should
-     *                      show the fallback reply. Leave true for non-threaded
-     *                      timelines.
-     */
-    static bool hasReply(const Quotient::RoomEvent *event, bool showFallbacks = true);
-
-    /**
-     * @brief Return the Matrix ID of the event replied to.
-     */
-    static QString replyId(const Quotient::RoomEvent *event);
-
     /**
      * @brief Get the author of the event replied to in context of the room.
      *
@@ -249,20 +227,6 @@ public:
      */
     static Quotient::RoomMember replyAuthor(const NeoChatRoom *room, const Quotient::RoomEvent *event);
 
-    /**
-     * @brief Whether the message is part of a thread.
-     *
-     * i.e. There is a rel_type of m.thread.
-     */
-    static bool isThreaded(const Quotient::RoomEvent *event);
-
-    /**
-     * @brief Return the Matrix ID of the thread's root message.
-     *
-     * Empty if this not part of a thread.
-     */
-    static QString threadRoot(const Quotient::RoomEvent *event);
-
     /**
      * @brief Return the latitude for the event.
      *
