@@ -7,25 +7,13 @@
 
 #include <Quotient/accountregistry.h>
 #include <Quotient/e2ee/sssshandler.h>
+#include <Quotient/keyimport.h>
 #include <Quotient/keyverificationsession.h>
 #include <Quotient/roommember.h>
 
 #include "controller.h"
 #include "neochatconfig.h"
 
-struct ForeignConfig {
-    Q_GADGET
-    QML_FOREIGN(NeoChatConfig)
-    QML_NAMED_ELEMENT(Config)
-    QML_SINGLETON
-public:
-    static NeoChatConfig *create(QQmlEngine *, QJSEngine *)
-    {
-        QQmlEngine::setObjectOwnership(NeoChatConfig::self(), QQmlEngine::CppOwnership);
-        return NeoChatConfig::self();
-    }
-};
-
 struct ForeignAccountRegistry {
     Q_GADGET
     QML_FOREIGN(Quotient::AccountRegistry)
@@ -51,3 +39,10 @@ struct ForeignSSSSHandler {
     QML_FOREIGN(Quotient::SSSSHandler)
     QML_NAMED_ELEMENT(SSSSHandler)
 };
+
+struct ForeignKeyImport {
+    Q_GADGET
+    QML_SINGLETON
+    QML_FOREIGN(Quotient::KeyImport)
+    QML_NAMED_ELEMENT(KeyImport)
+};
