@@ -78,11 +78,11 @@ class NetworkAccessManagerFactory : public QQmlNetworkAccessManagerFactory
         auto nam = NetworkAccessManager::instance();
         nam->setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
 
-        nam->enableStrictTransportSecurityStore(true, QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/hsts/"));
+        nam->enableStrictTransportSecurityStore(true, QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + u"/hsts/"_s);
         nam->setStrictTransportSecurityEnabled(true);
 
         auto namDiskCache = new QNetworkDiskCache(nam);
-        namDiskCache->setCacheDirectory(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/nam/"));
+        namDiskCache->setCacheDirectory(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + u"/nam/"_s);
         nam->setCache(namDiskCache);
 
         return nam;
@@ -113,13 +113,13 @@ int main(int argc, char *argv[])
 
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
-    QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
+    QQuickStyle::setStyle(u"org.kde.breeze"_s);
 #else
-    QIcon::setFallbackThemeName("breeze"_ls);
+    QIcon::setFallbackThemeName("breeze"_L1);
     QApplication app(argc, argv);
     // Default to org.kde.desktop style unless the user forces another style
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
-        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+        QQuickStyle::setStyle(u"org.kde.desktop"_s);
     }
 #endif
 
@@ -129,45 +129,46 @@ int main(int argc, char *argv[])
         freopen("CONOUT$", "w", stderr);
     }
 
-    QApplication::setStyle(QStringLiteral("breeze"));
-    QFont font(QStringLiteral("Segoe UI Emoji"));
+    QApplication::setStyle(u"breeze"_s);
+    QFont font(u"Segoe UI Emoji"_s);
     font.setPointSize(10);
     font.setHintingPreference(QFont::PreferNoHinting);
     app.setFont(font);
 #endif
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("neochat"));
 
-    QGuiApplication::setOrganizationName("KDE"_ls);
+    QGuiApplication::setOrganizationName("KDE"_L1);
 
-    KAboutData about(QStringLiteral("neochat"),
+    KAboutData about(u"neochat"_s,
                      i18n("NeoChat"),
                      QStringLiteral(NEOCHAT_VERSION_STRING),
                      i18n("Chat on Matrix"),
                      KAboutLicense::GPL_V3,
                      i18n("© 2018-2020 Black Hat, 2020-2024 KDE Community"));
-    about.addAuthor(i18n("Carl Schwan"),
+    about.addAuthor(i18n("Carl Schwan"), i18n("Maintainer"), u"carl@carlschwan.eu"_s, u"https://carlschwan.eu"_s, QUrl(u"https://carlschwan.eu/avatar.png"_s));
+    about.addAuthor(i18n("Tobias Fella"), i18n("Maintainer"), u"tobias.fella@kde.org"_s, u"https://tobiasfella.de"_s);
+    about.addAuthor(i18n("James Graham"), i18n("Maintainer"), u"james.h.graham@protonmail.com"_s);
+    about.addAuthor(i18n("Joshua Goins"),
                     i18n("Maintainer"),
-                    QStringLiteral("carl@carlschwan.eu"),
-                    QStringLiteral("https://carlschwan.eu"),
-                    QUrl(QStringLiteral("https://carlschwan.eu/avatar.png")));
-    about.addAuthor(i18n("Tobias Fella"), i18n("Maintainer"), QStringLiteral("tobias.fella@kde.org"), QStringLiteral("https://tobiasfella.de"));
-    about.addAuthor(i18n("James Graham"), i18n("Maintainer"), QStringLiteral("james.h.graham@protonmail.com"));
-    about.addCredit(i18n("Black Hat"), i18n("Original author of Spectral"), QStringLiteral("bhat@encom.eu.org"));
-    about.addCredit(i18n("Alexey Rusakov"), i18n("Maintainer of libQuotient"), QStringLiteral("Kitsune-Ral@users.sf.net"));
+                    u"josh@redstrate.com"_s,
+                    u"https://redstrate.com/"_s,
+                    QUrl(u"https://redstrate.com/rss-image.png"_s));
+    about.addCredit(i18n("Black Hat"), i18n("Original author of Spectral"), u"bhat@encom.eu.org"_s);
+    about.addCredit(i18n("Alexey Rusakov"), i18n("Maintainer of libQuotient"), u"Kitsune-Ral@users.sf.net"_s);
     about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     about.setOrganizationDomain("kde.org");
 
-    about.addComponent(QStringLiteral("libQuotient"),
+    about.addComponent(u"libQuotient"_s,
                        i18n("A Qt library to write cross-platform clients for Matrix"),
                        i18nc("<version number> (built against <possibly different version number>)",
                              "%1 (built against %2)",
                              Quotient::versionString(),
                              QStringLiteral(Quotient_VERSION_STRING)),
-                       QStringLiteral("https://github.com/quotient-im/libquotient"),
+                       u"https://github.com/quotient-im/libquotient"_s,
                        KAboutLicense::LGPL_V2_1);
 
     KAboutData::setApplicationData(about);
-    QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.neochat")));
+    QGuiApplication::setWindowIcon(QIcon::fromTheme(u"org.kde.neochat"_s));
 
 #if __has_include("KCrash")
     KCrash::initialize();
@@ -181,34 +182,33 @@ int main(int argc, char *argv[])
 #ifdef NEOCHAT_FLATPAK
     // Copy over the included FontConfig configuration to the
     // app's config dir:
-    QFile::copy(QStringLiteral("/app/etc/fonts/conf.d/99-noto-mono-color-emoji.conf"),
-                QStringLiteral("/var/config/fontconfig/conf.d/99-noto-mono-color-emoji.conf"));
+    QFile::copy(u"/app/etc/fonts/conf.d/99-noto-mono-color-emoji.conf"_s, u"/var/config/fontconfig/conf.d/99-noto-mono-color-emoji.conf"_s);
 #endif
 
     ColorSchemer colorScheme;
 
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("Client for the matrix communication protocol"));
-    parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports matrix: url scheme"));
-    parser.addOption(QCommandLineOption("ignore-ssl-errors"_ls, i18n("Ignore all SSL Errors, e.g., unsigned certificates.")));
+    parser.addPositionalArgument(u"urls"_s, i18n("Supports matrix: url scheme"));
+    parser.addOption(QCommandLineOption("ignore-ssl-errors"_L1, i18n("Ignore all SSL Errors, e.g., unsigned certificates.")));
 
-    QCommandLineOption testOption("test"_ls, i18n("Only used for autotests"));
+    QCommandLineOption testOption("test"_L1, i18n("Only used for autotests"));
     testOption.setFlags(QCommandLineOption::HiddenFromHelp);
     parser.addOption(testOption);
 
 #ifdef HAVE_KUNIFIEDPUSH
-    QCommandLineOption dbusActivatedOption(QStringLiteral("dbus-activated"), i18n("Internal usage only."));
+    QCommandLineOption dbusActivatedOption(u"dbus-activated"_s, i18n("Internal usage only."));
     dbusActivatedOption.setFlags(QCommandLineOption::Flag::HiddenFromHelp);
     parser.addOption(dbusActivatedOption);
 #endif
 
-    QCommandLineOption shareOption(QStringLiteral("share"), i18n("Share a URL to Matrix"), QStringLiteral("text"));
+    QCommandLineOption shareOption(u"share"_s, i18n("Share a URL to Matrix"), u"text"_s);
     parser.addOption(shareOption);
 
     about.setupCommandLine(&parser);
     parser.process(app);
     about.processCommandLine(&parser);
-    Controller::setTestMode(parser.isSet("test"_ls));
+    Controller::setTestMode(parser.isSet("test"_L1));
 
 #ifdef HAVE_KUNIFIEDPUSH
     if (parser.isSet(dbusActivatedOption)) {
@@ -220,7 +220,7 @@ int main(int argc, char *argv[])
         // Because KRunner may call us on the D-Bus (under the same service name org.kde.neochat) then it may
         // accidentally activate us for push notifications instead. If this happens, then immediately quit if the fake
         // runner is called.
-        QDBusConnection::sessionBus().registerObject("/RoomRunner"_ls, new FakeRunner(), QDBusConnection::ExportScriptableContents);
+        QDBusConnection::sessionBus().registerObject("/RoomRunner"_L1, new FakeRunner(), QDBusConnection::ExportScriptableContents);
 #endif
 
         Controller::listenForNotifications();
@@ -239,6 +239,7 @@ int main(int argc, char *argv[])
     Q_IMPORT_QML_PLUGIN(org_kde_neochat_chatbarPlugin)
 
     qml_register_types_org_kde_neochat();
+    qmlRegisterUncreatableMetaObject(Quotient::staticMetaObject, "Quotient", 1, 0, "JoinRule", u"Access to JoinRule enum only"_s);
 
     QQmlApplicationEngine engine;
 
@@ -261,7 +262,7 @@ int main(int argc, char *argv[])
 
             auto args = arguments;
             args.removeFirst();
-            if (args.length() == 2 && args[0] == "--share"_ls) {
+            if (args.length() == 2 && args[0] == "--share"_L1) {
                 ShareHandler::instance().setText(args[1]);
                 return;
             }
@@ -273,33 +274,32 @@ int main(int argc, char *argv[])
 #endif
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    QObject::connect(&engine, &QQmlApplicationEngine::quit, &app, &QCoreApplication::quit);
     engine.setNetworkAccessManagerFactory(new NetworkAccessManagerFactory());
 
-    if (parser.isSet("ignore-ssl-errors"_ls)) {
+    if (parser.isSet("ignore-ssl-errors"_L1)) {
         QObject::connect(NetworkAccessManager::instance(), &QNetworkAccessManager::sslErrors, NetworkAccessManager::instance(), [](QNetworkReply *reply) {
             reply->ignoreSslErrors();
         });
     }
 
-    if (parser.isSet("share"_ls)) {
+    if (parser.isSet("share"_L1)) {
         ShareHandler::instance().setText(parser.value(shareOption));
     }
 
-    engine.addImageProvider(QLatin1String("blurhash"), new BlurhashImageProvider);
+    engine.addImageProvider(u"blurhash"_s, new BlurhashImageProvider);
 
     engine.loadFromModule("org.kde.neochat", "Main");
     if (engine.rootObjects().isEmpty()) {
         return -1;
     }
 
-    if (!parser.positionalArguments().isEmpty() && !parser.isSet("share"_ls)) {
+    if (!parser.positionalArguments().isEmpty() && !parser.isSet("share"_L1)) {
         RoomManager::instance().setUrlArgument(parser.positionalArguments()[0]);
     }
 
 #ifdef HAVE_RUNNER
     auto runner = Runner::create(&engine, &engine);
-    QDBusConnection::sessionBus().registerObject("/RoomRunner"_ls, runner, QDBusConnection::ExportScriptableContents);
+    QDBusConnection::sessionBus().registerObject("/RoomRunner"_L1, runner, QDBusConnection::ExportScriptableContents);
 #endif
 
     QWindow *window = windowFromEngine(&engine);
