@@ -3,12 +3,15 @@
 
 #pragma once
 
+#include <QQmlEngine>
 #include <QSortFilterProxyModel>
 
 class DevicesProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
-    Q_PROPERTY(int type READ type WRITE setType NOTIFY typeChanged);
+    QML_ELEMENT
+
+    Q_PROPERTY(int type READ type WRITE setType NOTIFY typeChanged)
 
 public:
     DevicesProxyModel(QObject *parent = nullptr);
