@@ -3,6 +3,7 @@
 
 #include "messagecontentmodel.h"
 #include "eventhandler.h"
+#include "messagecomponenttype.h"
 #include "neochatconfig.h"
 
 #include <QImageReader>
@@ -12,6 +13,9 @@
 #include <Quotient/events/roommessageevent.h>
 #include <Quotient/events/stickerevent.h>
 #include <Quotient/qt_connection_util.h>
+#if Quotient_VERSION_MINOR > 9 || (Quotient_VERSION_MINOR == 9 && Quotient_VERSION_PATCH > 1)
+#include <Quotient/thread.h>
+#endif
 
 #include <KLocalizedString>
 #include <Kirigami/Platform/PlatformTheme>
@@ -24,6 +28,7 @@
 #include "chatbarcache.h"
 #include "filetype.h"
 #include "linkpreviewer.h"
+#include "models/reactionmodel.h"
 #include "neochatconnection.h"
 #include "neochatroom.h"
 #include "texthandler.h"
@@ -34,7 +39,7 @@ MessageContentModel::MessageContentModel(NeoChatRoom *room, const QString &event
     : QAbstractListModel(parent)
     , m_room(room)
     , m_eventId(eventId)
-    , m_isPending(isPending)
+    , m_currentState(isPending ? Pending : Unknown)
     , m_isReply(isReply)
 {
     initializeModel();
@@ -45,19 +50,27 @@ void MessageContentModel::initializeModel()
     Q_ASSERT(m_room != nullptr);
     Q_ASSERT(!m_eventId.isEmpty());
 
-    connect(this, &MessageContentModel::eventUnavailable, this, &MessageContentModel::getEvent);
-
+    connect(m_room, &NeoChatRoom::pendingEventAdded, this, [this]() {
+        if (m_room != nullptr && m_currentState == Unknown) {
+            initializeEvent();
+            updateReplyModel();
+            resetModel();
+        }
+    });
     connect(m_room, &NeoChatRoom::pendingEventAboutToMerge, this, [this](Quotient::RoomEvent *serverEvent) {
         if (m_room != nullptr) {
             if (m_eventId == serverEvent->id() || m_eventId == serverEvent->transactionId()) {
-                beginResetModel();
-                m_isPending = false;
                 m_eventId = serverEvent->id();
-                initializeEvent();
-                endResetModel();
             }
         }
     });
+    connect(m_room, &NeoChatRoom::pendingEventMerged, this, [this]() {
+        if (m_room != nullptr && m_currentState == Pending) {
+            initializeEvent();
+            updateReplyModel();
+            resetModel();
+        }
+    });
     connect(m_room, &NeoChatRoom::addedMessages, this, [this](int fromIndex, int toIndex) {
         if (m_room != nullptr) {
             for (int i = fromIndex; i <= toIndex; i++) {
@@ -119,19 +132,16 @@ void MessageContentModel::initializeModel()
     connect(m_room, &NeoChatRoom::urlPreviewEnabledChanged, this, [this]() {
         resetContent();
     });
-    connect(NeoChatConfig::self(), &NeoChatConfig::ShowLinkPreviewChanged, this, [this]() {
-        resetContent();
-    });
     connect(m_room, &Room::memberNameUpdated, this, [this](RoomMember member) {
         if (m_room != nullptr) {
-            if (m_eventSenderId.isEmpty() || m_eventSenderId == member.id()) {
+            if (senderId().isEmpty() || senderId() == member.id()) {
                 Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0), {AuthorRole});
             }
         }
     });
     connect(m_room, &Room::memberAvatarUpdated, this, [this](RoomMember member) {
         if (m_room != nullptr) {
-            if (m_eventSenderId.isEmpty() || m_eventSenderId == member.id()) {
+            if (senderId().isEmpty() || senderId() == member.id()) {
                 Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0), {AuthorRole});
             }
         }
@@ -141,28 +151,37 @@ void MessageContentModel::initializeModel()
         updateReplyModel();
         resetModel();
     });
+    connect(m_room, &Room::updatedEvent, this, [this](const QString &eventId) {
+        if (eventId == m_eventId) {
+            updateReactionModel();
+        }
+    });
 
     initializeEvent();
-    updateReplyModel();
+    if (m_currentState == Available || m_currentState == Pending) {
+        updateReplyModel();
+    }
     resetModel();
+    updateReactionModel();
 }
 
 void MessageContentModel::initializeEvent()
 {
-    const auto event = m_room->getEvent(m_eventId);
-    if (event == nullptr) {
-        Q_EMIT eventUnavailable();
+    if (m_currentState == UnAvailable) {
         return;
     }
 
-    if (m_eventSenderObject == nullptr) {
-        auto senderId = event->senderId();
-        // A pending event might not have a sender ID set yet but in that case it must
-        // be the local member.
-        if (senderId.isEmpty()) {
-            senderId = m_room->localMember().id();
+    const auto eventResult = m_room->getEvent(m_eventId);
+    if (eventResult.first == nullptr) {
+        if (m_currentState != Pending) {
+            getEvent();
         }
-        m_eventSenderObject = std::unique_ptr<NeochatRoomMember>(new NeochatRoomMember(m_room, senderId));
+        return;
+    }
+    if (eventResult.second) {
+        m_currentState = Pending;
+    } else {
+        m_currentState = Available;
     }
     Q_EMIT eventUpdated();
 }
@@ -172,7 +191,6 @@ void MessageContentModel::getEvent()
     Quotient::connectUntil(m_room.get(), &NeoChatRoom::extraEventLoaded, this, [this](const QString &eventId) {
         if (m_room != nullptr) {
             if (eventId == m_eventId) {
-                m_notFound = false;
                 initializeEvent();
                 updateReplyModel();
                 resetModel();
@@ -184,7 +202,7 @@ void MessageContentModel::getEvent()
     Quotient::connectUntil(m_room.get(), &NeoChatRoom::extraEventNotFound, this, [this](const QString &eventId) {
         if (m_room != nullptr) {
             if (eventId == m_eventId) {
-                m_notFound = true;
+                m_currentState = UnAvailable;
                 resetModel();
                 return true;
             }
@@ -195,30 +213,29 @@ void MessageContentModel::getEvent()
     m_room->downloadEventFromServer(m_eventId);
 }
 
-bool MessageContentModel::showAuthor() const
+QString MessageContentModel::senderId() const
 {
-    return m_showAuthor;
+    const auto eventResult = m_room->getEvent(m_eventId);
+    if (eventResult.first == nullptr) {
+        return {};
+    }
+    auto senderId = eventResult.first->senderId();
+    if (senderId.isEmpty()) {
+        senderId = m_room->localMember().id();
+    }
+    return senderId;
 }
 
-void MessageContentModel::setShowAuthor(bool showAuthor)
+NeochatRoomMember *MessageContentModel::senderObject() const
 {
-    if (showAuthor == m_showAuthor) {
-        return;
+    const auto eventResult = m_room->getEvent(m_eventId);
+    if (eventResult.first == nullptr) {
+        return nullptr;
     }
-    m_showAuthor = showAuthor;
-
-    if (m_room->connection()->isIgnored(m_eventSenderId)) {
-        if (showAuthor) {
-            beginInsertRows({}, 0, 0);
-            m_components.prepend(MessageComponent{MessageComponentType::Author, QString(), {}});
-            endInsertRows();
-        } else {
-            beginRemoveRows({}, 0, 0);
-            m_components.remove(0, 1);
-            endRemoveRows();
-        }
+    if (eventResult.first->senderId().isEmpty()) {
+        return m_room->qmlSafeMember(m_room->localMember().id());
     }
-    Q_EMIT showAuthorChanged();
+    return m_room->qmlSafeMember(eventResult.first->senderId());
 }
 
 static LinkPreviewer *emptyLinkPreview = new LinkPreviewer;
@@ -237,7 +254,7 @@ QVariant MessageContentModel::data(const QModelIndex &index, int role) const
     const auto component = m_components[index.row()];
 
     const auto event = m_room->getEvent(m_eventId);
-    if (event == nullptr) {
+    if (event.first == nullptr) {
         if (role == DisplayRole) {
             if (m_isReply) {
                 return i18n("Loading reply");
@@ -252,7 +269,7 @@ QVariant MessageContentModel::data(const QModelIndex &index, int role) const
     }
 
     if (role == DisplayRole) {
-        if (m_notFound || m_room->connection()->isIgnored(m_eventSenderId)) {
+        if (m_currentState == UnAvailable || m_room->connection()->isIgnored(senderId())) {
             Kirigami::Platform::PlatformTheme *theme =
                 static_cast<Kirigami::Platform::PlatformTheme *>(qmlAttachedPropertiesObject<Kirigami::Platform::PlatformTheme>(this, true));
 
@@ -260,11 +277,11 @@ QVariant MessageContentModel::data(const QModelIndex &index, int role) const
             if (theme != nullptr) {
                 disabledTextColor = theme->disabledTextColor().name();
             } else {
-                disabledTextColor = QStringLiteral("#000000");
+                disabledTextColor = u"#000000"_s;
             }
-            return QString(QStringLiteral("<span style=\"color:%1\">").arg(disabledTextColor)
+            return QString(u"<span style=\"color:%1\">"_s.arg(disabledTextColor)
                            + i18nc("@info", "This message was either not found, you do not have permission to view it, or it was sent by an ignored user")
-                           + QStringLiteral("</span>"));
+                           + u"</span>"_s);
         }
         if (component.type == MessageComponentType::Loading) {
             if (m_isReply) {
@@ -276,7 +293,7 @@ QVariant MessageContentModel::data(const QModelIndex &index, int role) const
         if (!component.content.isEmpty()) {
             return component.content;
         }
-        return EventHandler::richBody(m_room, event);
+        return EventHandler::richBody(m_room, event.first);
     }
     if (role == ComponentTypeRole) {
         return component.type;
@@ -285,61 +302,68 @@ QVariant MessageContentModel::data(const QModelIndex &index, int role) const
         return component.attributes;
     }
     if (role == EventIdRole) {
-        return EventHandler::id(event);
+        return event.first->displayId();
     }
     if (role == TimeRole) {
-        const auto pendingIt = std::find_if(m_room->pendingEvents().cbegin(), m_room->pendingEvents().cend(), [event](const PendingEventItem &pendingEvent) {
-            return event->transactionId() == pendingEvent->transactionId();
-        });
-
-        auto lastUpdated = pendingIt == m_room->pendingEvents().cend() ? QDateTime() : pendingIt->lastUpdated();
-        return EventHandler::time(event, m_isPending, lastUpdated);
+        return EventHandler::time(m_room, event.first, m_currentState == Pending);
     }
     if (role == TimeStringRole) {
-        const auto pendingIt = std::find_if(m_room->pendingEvents().cbegin(), m_room->pendingEvents().cend(), [event](const PendingEventItem &pendingEvent) {
-            return event->transactionId() == pendingEvent->transactionId();
-        });
-
-        auto lastUpdated = pendingIt == m_room->pendingEvents().cend() ? QDateTime() : pendingIt->lastUpdated();
-        return EventHandler::timeString(event, QStringLiteral("hh:mm"), m_isPending, lastUpdated);
+        return EventHandler::timeString(m_room, event.first, u"hh:mm"_s, m_currentState == Pending);
     }
     if (role == AuthorRole) {
-        return QVariant::fromValue<NeochatRoomMember *>(m_eventSenderObject.get());
+        return QVariant::fromValue<NeochatRoomMember *>(senderObject());
     }
     if (role == MediaInfoRole) {
-        return EventHandler::mediaInfo(m_room, event);
+        return EventHandler::mediaInfo(m_room, event.first);
     }
     if (role == FileTransferInfoRole) {
-        return QVariant::fromValue(m_room->cachedFileTransferInfo(event));
+        return QVariant::fromValue(m_room->cachedFileTransferInfo(event.first));
     }
     if (role == ItineraryModelRole) {
         return QVariant::fromValue<ItineraryModel *>(m_itineraryModel);
     }
     if (role == LatitudeRole) {
-        return EventHandler::latitude(event);
+        return EventHandler::latitude(event.first);
     }
     if (role == LongitudeRole) {
-        return EventHandler::longitude(event);
+        return EventHandler::longitude(event.first);
     }
     if (role == AssetRole) {
-        return EventHandler::locationAssetType(event);
+        return EventHandler::locationAssetType(event.first);
     }
     if (role == PollHandlerRole) {
         return QVariant::fromValue<PollHandler *>(m_room->poll(m_eventId));
     }
     if (role == ReplyEventIdRole) {
-        return EventHandler::replyId(event);
+        if (const auto roomMessageEvent = eventCast<const RoomMessageEvent>(event.first)) {
+            return roomMessageEvent->replyEventId();
+        }
     }
     if (role == ReplyAuthorRole) {
-        return QVariant::fromValue(EventHandler::replyAuthor(m_room, event));
+        return QVariant::fromValue(EventHandler::replyAuthor(m_room, event.first));
     }
     if (role == ReplyContentModelRole) {
         return QVariant::fromValue<MessageContentModel *>(m_replyModel);
     }
+    if (role == ReactionModelRole) {
+        return QVariant::fromValue<ReactionModel *>(m_reactionModel);
+        ;
+    }
+    if (role == ThreadRootRole) {
+        auto roomMessageEvent = eventCast<const RoomMessageEvent>(event.first);
+#if Quotient_VERSION_MINOR > 9 || (Quotient_VERSION_MINOR == 9 && Quotient_VERSION_PATCH > 1)
+        if (roomMessageEvent && (roomMessageEvent->isThreaded() || m_room->threads().contains(roomMessageEvent->id()))) {
+#else
+        if (roomMessageEvent && roomMessageEvent->isThreaded()) {
+#endif
+            return roomMessageEvent->threadRootEventId();
+        }
+        return {};
+    }
     if (role == LinkPreviewerRole) {
         if (component.type == MessageComponentType::LinkPreview) {
             return QVariant::fromValue<LinkPreviewer *>(
-                dynamic_cast<NeoChatConnection *>(m_room->connection())->previewerForLink(component.attributes["link"_ls].toUrl()));
+                dynamic_cast<NeoChatConnection *>(m_room->connection())->previewerForLink(component.attributes["link"_L1].toUrl()));
         } else {
             return QVariant::fromValue<LinkPreviewer *>(emptyLinkPreview);
         }
@@ -362,51 +386,55 @@ int MessageContentModel::rowCount(const QModelIndex &parent) const
 
 QHash<int, QByteArray> MessageContentModel::roleNames() const
 {
-    QHash<int, QByteArray> roles = QAbstractItemModel::roleNames();
-    roles[DisplayRole] = "display";
-    roles[ComponentTypeRole] = "componentType";
-    roles[ComponentAttributesRole] = "componentAttributes";
-    roles[EventIdRole] = "eventId";
-    roles[TimeRole] = "time";
-    roles[TimeStringRole] = "timeString";
-    roles[AuthorRole] = "author";
-    roles[MediaInfoRole] = "mediaInfo";
-    roles[FileTransferInfoRole] = "fileTransferInfo";
-    roles[ItineraryModelRole] = "itineraryModel";
-    roles[LatitudeRole] = "latitude";
-    roles[LongitudeRole] = "longitude";
-    roles[AssetRole] = "asset";
-    roles[PollHandlerRole] = "pollHandler";
-    roles[ReplyEventIdRole] = "replyEventId";
-    roles[ReplyAuthorRole] = "replyAuthor";
-    roles[ReplyContentModelRole] = "replyContentModel";
-    roles[LinkPreviewerRole] = "linkPreviewer";
-    roles[ChatBarCacheRole] = "chatBarCache";
+    return roleNamesStatic();
+}
+
+QHash<int, QByteArray> MessageContentModel::roleNamesStatic()
+{
+    QHash<int, QByteArray> roles;
+    roles[MessageContentModel::DisplayRole] = "display";
+    roles[MessageContentModel::ComponentTypeRole] = "componentType";
+    roles[MessageContentModel::ComponentAttributesRole] = "componentAttributes";
+    roles[MessageContentModel::EventIdRole] = "eventId";
+    roles[MessageContentModel::TimeRole] = "time";
+    roles[MessageContentModel::TimeStringRole] = "timeString";
+    roles[MessageContentModel::AuthorRole] = "author";
+    roles[MessageContentModel::MediaInfoRole] = "mediaInfo";
+    roles[MessageContentModel::FileTransferInfoRole] = "fileTransferInfo";
+    roles[MessageContentModel::ItineraryModelRole] = "itineraryModel";
+    roles[MessageContentModel::LatitudeRole] = "latitude";
+    roles[MessageContentModel::LongitudeRole] = "longitude";
+    roles[MessageContentModel::AssetRole] = "asset";
+    roles[MessageContentModel::PollHandlerRole] = "pollHandler";
+    roles[MessageContentModel::ReplyEventIdRole] = "replyEventId";
+    roles[MessageContentModel::ReplyAuthorRole] = "replyAuthor";
+    roles[MessageContentModel::ReplyContentModelRole] = "replyContentModel";
+    roles[MessageContentModel::ReactionModelRole] = "reactionModel";
+    roles[MessageContentModel::ThreadRootRole] = "threadRoot";
+    roles[MessageContentModel::LinkPreviewerRole] = "linkPreviewer";
+    roles[MessageContentModel::ChatBarCacheRole] = "chatBarCache";
     return roles;
 }
 
 void MessageContentModel::resetModel()
 {
-    const auto event = m_room->getEvent(m_eventId);
-
     beginResetModel();
     m_components.clear();
 
-    if (m_room->connection()->isIgnored(m_eventSenderId) || m_notFound) {
+    if (m_room->connection()->isIgnored(senderId()) || m_currentState == UnAvailable) {
         m_components += MessageComponent{MessageComponentType::Text, QString(), {}};
         endResetModel();
         return;
     }
 
-    if (event == nullptr) {
+    const auto event = m_room->getEvent(m_eventId);
+    if (event.first == nullptr) {
         m_components += MessageComponent{MessageComponentType::Loading, QString(), {}};
         endResetModel();
         return;
     }
 
-    if (m_showAuthor) {
-        m_components += MessageComponent{MessageComponentType::Author, QString(), {}};
-    }
+    m_components += MessageComponent{MessageComponentType::Author, QString(), {}};
 
     m_components += messageContentComponents();
     endResetModel();
@@ -431,19 +459,19 @@ void MessageContentModel::resetContent(bool isEditing, bool isThreading)
 QList<MessageComponent> MessageContentModel::messageContentComponents(bool isEditing, bool isThreading)
 {
     const auto event = m_room->getEvent(m_eventId);
-    if (event == nullptr) {
+    if (event.first == nullptr) {
         return {};
     }
 
     QList<MessageComponent> newComponents;
 
-    if (eventCast<const Quotient::RoomMessageEvent>(event)
-        && eventCast<const Quotient::RoomMessageEvent>(event)->rawMsgtype() == QStringLiteral("m.key.verification.request")) {
+    const auto roomMessageEvent = eventCast<const Quotient::RoomMessageEvent>(event.first);
+    if (roomMessageEvent && roomMessageEvent->rawMsgtype() == u"m.key.verification.request"_s) {
         newComponents += MessageComponent{MessageComponentType::Verification, QString(), {}};
         return newComponents;
     }
 
-    if (event->isRedacted()) {
+    if (event.first->isRedacted()) {
         newComponents += MessageComponent{MessageComponentType::Text, QString(), {}};
         return newComponents;
     }
@@ -455,15 +483,34 @@ QList<MessageComponent> MessageContentModel::messageContentComponents(bool isEdi
     if (isEditing) {
         newComponents += MessageComponent{MessageComponentType::ChatBar, QString(), {}};
     } else {
-        newComponents.append(componentsForType(MessageComponentType::typeForEvent(*event)));
+        newComponents.append(componentsForType(MessageComponentType::typeForEvent(*event.first)));
     }
 
     if (m_room->urlPreviewEnabled()) {
         newComponents = addLinkPreviews(newComponents);
     }
 
+    if ((m_reactionModel && m_reactionModel->rowCount() > 0)) {
+        newComponents += MessageComponent{MessageComponentType::Reaction, QString(), {}};
+    }
+
+#if Quotient_VERSION_MINOR > 9 || (Quotient_VERSION_MINOR == 9 && Quotient_VERSION_PATCH > 1)
+    if (NeoChatConfig::self()->threads() && roomMessageEvent && (roomMessageEvent->isThreaded() || m_room->threads().contains(roomMessageEvent->id()))
+        && roomMessageEvent->id() == roomMessageEvent->threadRootEventId()) {
+#else
+    if (NeoChatConfig::self()->threads() && roomMessageEvent && roomMessageEvent->isThreaded()
+        && roomMessageEvent->id() == roomMessageEvent->threadRootEventId()) {
+#endif
+        newComponents += MessageComponent{MessageComponentType::Separator, {}, {}};
+        newComponents += MessageComponent{MessageComponentType::ThreadBody, u"Thread Body"_s, {}};
+    }
+
     // If the event is already threaded the ThreadModel will handle displaying a chat bar.
-    if (isThreading && !EventHandler::isThreaded(event)) {
+#if Quotient_VERSION_MINOR > 9 || (Quotient_VERSION_MINOR == 9 && Quotient_VERSION_PATCH > 1)
+    if (isThreading && roomMessageEvent && !(roomMessageEvent->isThreaded() || m_room->threads().contains(roomMessageEvent->id()))) {
+#else
+    if (isThreading && roomMessageEvent && roomMessageEvent->isThreaded()) {
+#endif
         newComponents += MessageComponent{MessageComponentType::ChatBar, QString(), {}};
     }
 
@@ -473,11 +520,15 @@ QList<MessageComponent> MessageContentModel::messageContentComponents(bool isEdi
 void MessageContentModel::updateReplyModel()
 {
     const auto event = m_room->getEvent(m_eventId);
-    if (event == nullptr || m_isReply) {
+    if (event.first == nullptr || m_isReply) {
         return;
     }
 
-    if (!EventHandler::hasReply(event) || (EventHandler::isThreaded(event) && NeoChatConfig::self()->threads())) {
+    const auto roomMessageEvent = eventCast<const Quotient::RoomMessageEvent>(event.first);
+    if (roomMessageEvent == nullptr) {
+        return;
+    }
+    if (!roomMessageEvent->isReply(!NeoChatConfig::self()->threads()) || (roomMessageEvent->isThreaded() && NeoChatConfig::self()->threads())) {
         if (m_replyModel) {
             delete m_replyModel;
         }
@@ -488,7 +539,7 @@ void MessageContentModel::updateReplyModel()
         return;
     }
 
-    m_replyModel = new MessageContentModel(m_room, EventHandler::replyId(event), true, false, this);
+    m_replyModel = new MessageContentModel(m_room, roomMessageEvent->replyEventId(!NeoChatConfig::self()->threads()), true, false, this);
 
     connect(m_replyModel, &MessageContentModel::eventUpdated, this, [this]() {
         Q_EMIT dataChanged(index(0), index(0), {ReplyAuthorRole});
@@ -498,13 +549,13 @@ void MessageContentModel::updateReplyModel()
 QList<MessageComponent> MessageContentModel::componentsForType(MessageComponentType::Type type)
 {
     const auto event = m_room->getEvent(m_eventId);
-    if (event == nullptr) {
+    if (event.first == nullptr) {
         return {};
     }
 
     switch (type) {
     case MessageComponentType::Text: {
-        const auto roomMessageEvent = eventCast<const Quotient::RoomMessageEvent>(event);
+        const auto roomMessageEvent = eventCast<const Quotient::RoomMessageEvent>(event.first);
         auto body = EventHandler::rawMessageBody(*roomMessageEvent);
         return TextHandler().textComponents(body,
                                             EventHandler::messageBodyInputFormat(*roomMessageEvent),
@@ -515,16 +566,16 @@ QList<MessageComponent> MessageContentModel::componentsForType(MessageComponentT
     case MessageComponentType::File: {
         QList<MessageComponent> components;
         components += MessageComponent{MessageComponentType::File, QString(), {}};
-        const auto roomMessageEvent = eventCast<const Quotient::RoomMessageEvent>(event);
+        const auto roomMessageEvent = eventCast<const Quotient::RoomMessageEvent>(event.first);
 
         if (m_emptyItinerary) {
             if (!m_isReply) {
-                auto fileTransferInfo = m_room->cachedFileTransferInfo(event);
+                auto fileTransferInfo = m_room->cachedFileTransferInfo(event.first);
 
 #ifndef Q_OS_ANDROID
                 Q_ASSERT(roomMessageEvent->content() != nullptr && roomMessageEvent->has<EventContent::FileContent>());
                 const QMimeType mimeType = roomMessageEvent->get<EventContent::FileContent>()->mimeType;
-                if (mimeType.name() == QStringLiteral("text/plain") || mimeType.parentMimeTypes().contains(QStringLiteral("text/plain"))) {
+                if (mimeType.name() == u"text/plain"_s || mimeType.parentMimeTypes().contains(u"text/plain"_s)) {
                     QString originalName = roomMessageEvent->get<EventContent::FileContent>()->originalName;
                     if (originalName.isEmpty()) {
                         originalName = roomMessageEvent->plainBody();
@@ -539,13 +590,13 @@ QList<MessageComponent> MessageContentModel::componentsForType(MessageComponentT
                     file.open(QIODevice::ReadOnly);
                     components += MessageComponent{MessageComponentType::Code,
                                                    QString::fromStdString(file.readAll().toStdString()),
-                                                   {{QStringLiteral("class"), definitionForFile.name()}}};
+                                                   {{u"class"_s, definitionForFile.name()}}};
                 }
 #endif
 
                 if (FileType::instance().fileHasImage(fileTransferInfo.localPath)) {
                     QImageReader reader(fileTransferInfo.localPath.path());
-                    components += MessageComponent{MessageComponentType::Pdf, QString(), {{QStringLiteral("size"), reader.size()}}};
+                    components += MessageComponent{MessageComponentType::Pdf, QString(), {{u"size"_s, reader.size()}}};
                 }
             }
         } else if (m_itineraryModel != nullptr) {
@@ -567,8 +618,8 @@ QList<MessageComponent> MessageContentModel::componentsForType(MessageComponentT
     case MessageComponentType::Image:
     case MessageComponentType::Audio:
     case MessageComponentType::Video: {
-        if (!event->is<StickerEvent>()) {
-            const auto roomMessageEvent = eventCast<const Quotient::RoomMessageEvent>(event);
+        if (!event.first->is<StickerEvent>()) {
+            const auto roomMessageEvent = eventCast<const Quotient::RoomMessageEvent>(event.first);
             const auto fileContent = roomMessageEvent->get<EventContent::FileContentBase>();
             if (fileContent != nullptr) {
                 const auto fileInfo = fileContent->commonInfo();
@@ -587,6 +638,7 @@ QList<MessageComponent> MessageContentModel::componentsForType(MessageComponentT
             }
         }
     }
+        [[fallthrough]];
     default:
         return {MessageComponent{type, QString(), {}}};
     }
@@ -599,13 +651,13 @@ MessageComponent MessageContentModel::linkPreviewComponent(const QUrl &link)
         return {};
     }
     if (linkPreviewer->loaded()) {
-        return MessageComponent{MessageComponentType::LinkPreview, QString(), {{"link"_ls, link}}};
+        return MessageComponent{MessageComponentType::LinkPreview, QString(), {{"link"_L1, link}}};
     } else {
         connect(linkPreviewer, &LinkPreviewer::loadedChanged, this, [this, link]() {
             const auto linkPreviewer = dynamic_cast<NeoChatConnection *>(m_room->connection())->previewerForLink(link);
             if (linkPreviewer != nullptr && linkPreviewer->loaded()) {
                 for (auto &component : m_components) {
-                    if (component.attributes["link"_ls].toUrl() == link) {
+                    if (component.attributes["link"_L1].toUrl() == link) {
                         // HACK: Because DelegateChooser can't switch the delegate on dataChanged it has to think there is a new delegate.
                         beginResetModel();
                         component.type = MessageComponentType::LinkPreview;
@@ -614,7 +666,7 @@ MessageComponent MessageContentModel::linkPreviewComponent(const QUrl &link)
                 }
             }
         });
-        return MessageComponent{MessageComponentType::LinkPreviewLoad, QString(), {{"link"_ls, link}}};
+        return MessageComponent{MessageComponentType::LinkPreviewLoad, QString(), {{"link"_L1, link}}};
     }
 }
 
@@ -649,7 +701,7 @@ void MessageContentModel::closeLinkPreview(int row)
 
     if (m_components[row].type == MessageComponentType::LinkPreview || m_components[row].type == MessageComponentType::LinkPreviewLoad) {
         beginResetModel();
-        m_removedLinkPreviews += m_components[row].attributes["link"_ls].toUrl();
+        m_removedLinkPreviews += m_components[row].attributes["link"_L1].toUrl();
         m_components.remove(row);
         m_components.squeeze();
         endResetModel();
@@ -660,13 +712,13 @@ void MessageContentModel::closeLinkPreview(int row)
 void MessageContentModel::updateItineraryModel()
 {
     const auto event = m_room->getEvent(m_eventId);
-    if (m_room == nullptr || event == nullptr) {
+    if (m_room == nullptr || event.first == nullptr) {
         return;
     }
 
-    if (auto roomMessageEvent = eventCast<const Quotient::RoomMessageEvent>(event)) {
+    if (auto roomMessageEvent = eventCast<const Quotient::RoomMessageEvent>(event.first)) {
         if (roomMessageEvent->has<EventContent::FileContent>()) {
-            auto filePath = m_room->cachedFileTransferInfo(event).localPath;
+            auto filePath = m_room->cachedFileTransferInfo(event.first).localPath;
             if (filePath.isEmpty() && m_itineraryModel != nullptr) {
                 delete m_itineraryModel;
                 m_itineraryModel = nullptr;
@@ -694,4 +746,25 @@ void MessageContentModel::updateItineraryModel()
     }
 }
 
+void MessageContentModel::updateReactionModel()
+{
+    if (m_reactionModel != nullptr && m_reactionModel->rowCount() > 0) {
+        return;
+    }
+
+    if (m_reactionModel == nullptr) {
+        m_reactionModel = new ReactionModel(this, m_eventId, m_room);
+        connect(m_reactionModel, &ReactionModel::reactionsUpdated, this, &MessageContentModel::updateReactionModel);
+    }
+
+    if (m_reactionModel->rowCount() <= 0) {
+        m_reactionModel->disconnect(this);
+        delete m_reactionModel;
+        m_reactionModel = nullptr;
+        return;
+    }
+
+    resetContent();
+}
+
 #include "moc_messagecontentmodel.cpp"
