@@ -7,11 +7,11 @@
 #include <QQmlEngine>
 
 #include <Quotient/events/roomevent.h>
-#include <Quotient/room.h>
 
 #include "enums/messagecomponenttype.h"
 #include "itinerarymodel.h"
 #include "messagecomponent.h"
+#include "models/reactionmodel.h"
 #include "neochatroommember.h"
 
 /**
@@ -25,12 +25,15 @@ class MessageContentModel : public QAbstractListModel
     QML_ELEMENT
     QML_UNCREATABLE("")
 
-    /**
-     * @brief Whether the author component is being shown.
-     */
-    Q_PROPERTY(bool showAuthor READ showAuthor WRITE setShowAuthor NOTIFY showAuthorChanged)
-
 public:
+    enum MessageState {
+        Unknown, /**< The message state is unknown. */
+        Pending, /**< The message is a new pending message which the server has not yet acknowledged. */
+        Available, /**< The message is available and acknowledged by the server. */
+        UnAvailable, /**< The message can't be retrieved either because it doesn't exist or is blocked. */
+    };
+    Q_ENUM(MessageState)
+
     /**
      * @brief Defines the model roles.
      */
@@ -54,6 +57,10 @@ public:
         ReplyAuthorRole, /**< The author of the event that was replied to. */
         ReplyContentModelRole, /**< The MessageContentModel for the reply event. */
 
+        ReactionModelRole, /**< Reaction model for this event. */
+
+        ThreadRootRole, /**< The thread root event ID for the event. */
+
         LinkPreviewerRole, /**< The link preview details. */
         ChatBarCacheRole, /**< The ChatBarCache to use. */
     };
@@ -65,9 +72,6 @@ public:
                                  bool isPending = false,
                                  MessageContentModel *parent = nullptr);
 
-    bool showAuthor() const;
-    void setShowAuthor(bool showAuthor);
-
     /**
      * @brief Get the given role value at the given index.
      *
@@ -89,6 +93,8 @@ public:
      */
     [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
+    static QHash<int, QByteArray> roleNamesStatic();
+
     /**
      * @brief Close the link preview at the given index.
      *
@@ -98,19 +104,16 @@ public:
 
 Q_SIGNALS:
     void showAuthorChanged();
-    void eventUnavailable();
     void eventUpdated();
 
 private:
     QPointer<NeoChatRoom> m_room;
     QString m_eventId;
-    QString m_eventSenderId;
-    std::unique_ptr<NeochatRoomMember> m_eventSenderObject = nullptr;
+    QString senderId() const;
+    NeochatRoomMember *senderObject() const;
 
-    bool m_isPending;
-    bool m_showAuthor = true;
+    MessageState m_currentState = Unknown;
     bool m_isReply;
-    bool m_notFound = false;
 
     void initializeModel();
     void initializeEvent();
@@ -124,6 +127,7 @@ private:
     QPointer<MessageContentModel> m_replyModel;
     void updateReplyModel();
 
+    ReactionModel *m_reactionModel = nullptr;
     ItineraryModel *m_itineraryModel = nullptr;
 
     QList<MessageComponent> componentsForType(MessageComponentType::Type type);
@@ -134,4 +138,6 @@ private:
 
     void updateItineraryModel();
     bool m_emptyItinerary = false;
+
+    void updateReactionModel();
 };
