@@ -9,11 +9,11 @@
 #include "enums/delegatetype.h"
 #include "messagecontentmodel.h"
 #include "neochatconfig.h"
-#include "neochatroommember.h"
+#include "timelinemessagemodel.h"
 
 using namespace Quotient;
 
-MessageFilterModel::MessageFilterModel(QObject *parent, TimelineModel *sourceModel)
+MessageFilterModel::MessageFilterModel(QObject *parent, QAbstractItemModel *sourceModel)
     : QSortFilterProxyModel(parent)
 {
     Q_ASSERT(sourceModel);
@@ -49,18 +49,18 @@ bool MessageFilterModel::eventIsVisible(int sourceRow, const QModelIndex &source
     const QModelIndex index = sourceModel()->index(sourceRow, 0, sourceParent);
 
     // Don't show redacted (i.e. deleted) messages.
-    if (index.data(MessageEventModel::IsRedactedRole).toBool() && !NeoChatConfig::self()->showDeletedMessages()) {
+    if (index.data(TimelineMessageModel::IsRedactedRole).toBool() && !NeoChatConfig::self()->showDeletedMessages()) {
         return false;
     }
 
     // Don't show hidden or replaced messages.
-    const int specialMarks = index.data(MessageEventModel::SpecialMarksRole).toInt();
+    const int specialMarks = index.data(TimelineMessageModel::SpecialMarksRole).toInt();
     if (specialMarks == EventStatus::Hidden || specialMarks == EventStatus::Replaced) {
         return false;
     }
 
     // Don't show events with an unknown type.
-    const auto eventType = index.data(MessageEventModel::DelegateTypeRole).toInt();
+    const auto eventType = index.data(TimelineMessageModel::DelegateTypeRole).toInt();
     if (eventType == DelegateType::Other) {
         return false;
     }
@@ -69,8 +69,8 @@ bool MessageFilterModel::eventIsVisible(int sourceRow, const QModelIndex &source
     // same day as they will be grouped as a single delegate.
     const bool notLastRow = sourceRow < sourceModel()->rowCount() - 1;
     const bool previousEventIsState =
-        notLastRow ? sourceModel()->data(sourceModel()->index(sourceRow + 1, 0), MessageEventModel::DelegateTypeRole) == DelegateType::State : false;
-    const bool newDay = sourceModel()->data(sourceModel()->index(sourceRow, 0), MessageEventModel::ShowSectionRole).toBool();
+        notLastRow ? sourceModel()->data(sourceModel()->index(sourceRow + 1, 0), TimelineMessageModel::DelegateTypeRole) == DelegateType::State : false;
+    const bool newDay = sourceModel()->data(sourceModel()->index(sourceRow, 0), TimelineMessageModel::ShowSectionRole).toBool();
     if (eventType == DelegateType::State && notLastRow && previousEventIsState && !newDay) {
         return false;
     }
@@ -80,7 +80,7 @@ bool MessageFilterModel::eventIsVisible(int sourceRow, const QModelIndex &source
 
 QVariant MessageFilterModel::data(const QModelIndex &index, int role) const
 {
-    if (role == MessageEventModel::DelegateTypeRole && NeoChatConfig::self()->showAllEvents()) {
+    if (role == TimelineMessageModel::DelegateTypeRole && NeoChatConfig::self()->showAllEvents()) {
         if (!eventIsVisible(index.row(), index.parent())) {
             return DelegateType::Other;
         }
@@ -92,12 +92,8 @@ QVariant MessageFilterModel::data(const QModelIndex &index, int role) const
         return authorList(mapToSource(index).row());
     } else if (role == ExcessAuthorsRole) {
         return excessAuthors(mapToSource(index).row());
-    } else if (role == MessageEventModel::ContentModelRole) {
-        const auto model = qvariant_cast<MessageContentModel *>(mapToSource(index).data(MessageEventModel::ContentModelRole));
-        if (model != nullptr && !showAuthor(index)) {
-            model->setShowAuthor(false);
-        }
-        return QVariant::fromValue<MessageContentModel *>(model);
+    } else if (role == MessageModel::ShowAuthorRole) {
+        return showAuthor(index);
     }
     return QSortFilterProxyModel::data(index, role);
 }
@@ -119,12 +115,12 @@ bool MessageFilterModel::showAuthor(QModelIndex index) const
         // Note !itemData(i).empty() is a check for instances where rows have been removed, e.g. when the read marker is moved.
         // While the row is removed the subsequent row indexes are not changed so we need to skip over the removed index.
         // See - https://doc.qt.io/qt-5/qabstractitemmodel.html#beginRemoveRows
-        if (data(i, MessageEventModel::SpecialMarksRole) != EventStatus::Hidden && !itemData(i).empty()) {
-            return data(i, MessageEventModel::AuthorRole) != data(index, MessageEventModel::AuthorRole)
-                || data(i, MessageEventModel::DelegateTypeRole) == DelegateType::State
-                || data(i, MessageEventModel::TimeRole).toDateTime().msecsTo(data(index, MessageEventModel::TimeRole).toDateTime()) > 600000
-                || data(i, MessageEventModel::TimeRole).toDateTime().toLocalTime().date().day()
-                != data(index, MessageEventModel::TimeRole).toDateTime().toLocalTime().date().day();
+        if (data(i, TimelineMessageModel::SpecialMarksRole) != EventStatus::Hidden && !itemData(i).empty()) {
+            return data(i, TimelineMessageModel::AuthorRole) != data(index, TimelineMessageModel::AuthorRole)
+                || data(i, TimelineMessageModel::DelegateTypeRole) == DelegateType::State
+                || data(i, TimelineMessageModel::TimeRole).toDateTime().msecsTo(data(index, TimelineMessageModel::TimeRole).toDateTime()) > 600000
+                || data(i, TimelineMessageModel::TimeRole).toDateTime().toLocalTime().date().day()
+                != data(index, TimelineMessageModel::TimeRole).toDateTime().toLocalTime().date().day();
         }
     }
 
@@ -135,12 +131,12 @@ QString MessageFilterModel::aggregateEventToString(int sourceRow) const
 {
     QString aggregateString;
     for (int i = sourceRow; i >= 0; i--) {
-        aggregateString += sourceModel()->data(sourceModel()->index(i, 0), MessageEventModel::GenericDisplayRole).toString();
-        aggregateString += ", "_ls;
-        QVariant nextAuthor = sourceModel()->data(sourceModel()->index(i, 0), MessageEventModel::AuthorRole);
+        aggregateString += sourceModel()->data(sourceModel()->index(i, 0), TimelineMessageModel::GenericDisplayRole).toString();
+        aggregateString += ", "_L1;
+        QVariant nextAuthor = sourceModel()->data(sourceModel()->index(i, 0), TimelineMessageModel::AuthorRole);
         if (i > 0
-            && (sourceModel()->data(sourceModel()->index(i - 1, 0), MessageEventModel::DelegateTypeRole) != DelegateType::State // If it's not a state event
-                || sourceModel()->data(sourceModel()->index(i - 1, 0), MessageEventModel::ShowSectionRole).toBool() // or the section needs to be visible
+            && (sourceModel()->data(sourceModel()->index(i - 1, 0), TimelineMessageModel::DelegateTypeRole) != DelegateType::State // If it's not a state event
+                || sourceModel()->data(sourceModel()->index(i - 1, 0), TimelineMessageModel::ShowSectionRole).toBool() // or the section needs to be visible
                 )) {
             break;
         }
@@ -158,14 +154,14 @@ QVariantList MessageFilterModel::stateEventsList(int sourceRow) const
     QVariantList stateEvents;
     for (int i = sourceRow; i >= 0; i--) {
         auto nextState = QVariantMap{
-            {QStringLiteral("author"), sourceModel()->data(sourceModel()->index(i, 0), MessageEventModel::AuthorRole)},
-            {QStringLiteral("authorDisplayName"), sourceModel()->data(sourceModel()->index(i, 0), MessageEventModel::AuthorDisplayNameRole).toString()},
-            {QStringLiteral("text"), sourceModel()->data(sourceModel()->index(i, 0), Qt::DisplayRole).toString()},
+            {u"author"_s, sourceModel()->data(sourceModel()->index(i, 0), TimelineMessageModel::AuthorRole)},
+            {u"authorDisplayName"_s, sourceModel()->data(sourceModel()->index(i, 0), TimelineMessageModel::AuthorDisplayNameRole).toString()},
+            {u"text"_s, sourceModel()->data(sourceModel()->index(i, 0), Qt::DisplayRole).toString()},
         };
         stateEvents.append(nextState);
         if (i > 0
-            && (sourceModel()->data(sourceModel()->index(i - 1, 0), MessageEventModel::DelegateTypeRole) != DelegateType::State // If it's not a state event
-                || sourceModel()->data(sourceModel()->index(i - 1, 0), MessageEventModel::ShowSectionRole).toBool() // or the section needs to be visible
+            && (sourceModel()->data(sourceModel()->index(i - 1, 0), TimelineMessageModel::DelegateTypeRole) != DelegateType::State // If it's not a state event
+                || sourceModel()->data(sourceModel()->index(i - 1, 0), TimelineMessageModel::ShowSectionRole).toBool() // or the section needs to be visible
                 )) {
             break;
         }
@@ -177,13 +173,13 @@ QVariantList MessageFilterModel::authorList(int sourceRow) const
 {
     QVariantList uniqueAuthors;
     for (int i = sourceRow; i >= 0; i--) {
-        QVariant nextAvatar = sourceModel()->data(sourceModel()->index(i, 0), MessageEventModel::AuthorRole);
+        QVariant nextAvatar = sourceModel()->data(sourceModel()->index(i, 0), TimelineMessageModel::AuthorRole);
         if (!uniqueAuthors.contains(nextAvatar)) {
             uniqueAuthors.append(nextAvatar);
         }
         if (i > 0
-            && (sourceModel()->data(sourceModel()->index(i - 1, 0), MessageEventModel::DelegateTypeRole) != DelegateType::State // If it's not a state event
-                || sourceModel()->data(sourceModel()->index(i - 1, 0), MessageEventModel::ShowSectionRole).toBool() // or the section needs to be visible
+            && (sourceModel()->data(sourceModel()->index(i - 1, 0), TimelineMessageModel::DelegateTypeRole) != DelegateType::State // If it's not a state event
+                || sourceModel()->data(sourceModel()->index(i - 1, 0), TimelineMessageModel::ShowSectionRole).toBool() // or the section needs to be visible
                 )) {
             break;
         }
@@ -199,13 +195,13 @@ QString MessageFilterModel::excessAuthors(int row) const
 {
     QVariantList uniqueAuthors;
     for (int i = row; i >= 0; i--) {
-        QVariant nextAvatar = sourceModel()->data(sourceModel()->index(i, 0), MessageEventModel::AuthorRole);
+        QVariant nextAvatar = sourceModel()->data(sourceModel()->index(i, 0), TimelineMessageModel::AuthorRole);
         if (!uniqueAuthors.contains(nextAvatar)) {
             uniqueAuthors.append(nextAvatar);
         }
         if (i > 0
-            && (sourceModel()->data(sourceModel()->index(i - 1, 0), MessageEventModel::DelegateTypeRole) != DelegateType::State // If it's not a state event
-                || sourceModel()->data(sourceModel()->index(i - 1, 0), MessageEventModel::ShowSectionRole).toBool() // or the section needs to be visible
+            && (sourceModel()->data(sourceModel()->index(i - 1, 0), TimelineMessageModel::DelegateTypeRole) != DelegateType::State // If it's not a state event
+                || sourceModel()->data(sourceModel()->index(i - 1, 0), TimelineMessageModel::ShowSectionRole).toBool() // or the section needs to be visible
                 )) {
             break;
         }
@@ -221,7 +217,7 @@ QString MessageFilterModel::excessAuthors(int row) const
     if (excessAuthors == 0) {
         return QString();
     } else {
-        return QStringLiteral("+ %1").arg(excessAuthors);
+        return u"+ %1"_s.arg(excessAuthors);
     }
 }
 
