@@ -129,7 +129,7 @@ void RoomListModel::connectRoomSignals(NeoChatRoom *room)
         refresh(room);
     });
     connect(room, &Room::addedMessages, this, [this, room] {
-        refresh(room, {SubtitleTextRole, LastActiveTimeRole});
+        refresh(room, {SubtitleTextRole});
     });
     connect(room, &Room::pendingEventMerged, this, [this, room] {
         refresh(room, {SubtitleTextRole});
@@ -229,12 +229,9 @@ QVariant RoomListModel::data(const QModelIndex &index, int role) const
     if (role == HasHighlightNotificationsRole) {
         return room->highlightCount() > 0 && room->contextAwareNotificationCount() > 0;
     }
-    if (role == LastActiveTimeRole) {
-        return room->lastActiveTime();
-    }
     if (role == JoinStateRole) {
         if (!room->successorId().isEmpty()) {
-            return QStringLiteral("upgraded");
+            return u"upgraded"_s;
         }
         return QVariant::fromValue(room->joinState());
     }
@@ -291,7 +288,6 @@ QHash<int, QByteArray> RoomListModel::roleNames() const
     roles[CategoryRole] = "category";
     roles[ContextNotificationCountRole] = "contextNotificationCount";
     roles[HasHighlightNotificationsRole] = "hasHighlightNotifications";
-    roles[LastActiveTimeRole] = "lastActiveTime";
     roles[JoinStateRole] = "joinState";
     roles[CurrentRoomRole] = "currentRoom";
     roles[SubtitleTextRole] = "subtitleText";
