@@ -31,8 +31,11 @@ class NeoChatConnection : public Quotient::Connection
      * Set to an empty string to remove the label.
      */
     Q_PROPERTY(QString label READ label WRITE setLabel NOTIFY labelChanged)
-    Q_PROPERTY(QString deviceKey READ deviceKey CONSTANT)
-    Q_PROPERTY(QString encryptionKey READ encryptionKey CONSTANT)
+
+    /**
+     * @brief Whether URL previews are enabled globally.
+     */
+    Q_PROPERTY(bool globalUrlPreviewEnabled READ globalUrlPreviewEnabled WRITE setGlobalUrlPreviewEnabled NOTIFY globalUrlPreviewEnabledChanged)
 
     /**
      * @brief The model with the account's 3PIDs.
@@ -87,6 +90,21 @@ class NeoChatConnection : public Quotient::Connection
      */
     Q_PROPERTY(bool canCheckMutualRooms READ canCheckMutualRooms NOTIFY canCheckMutualRoomsChanged)
 
+    /**
+     * @brief Whether the server supports erasing user data when deactivating the account. This checks for MSC4025.
+     */
+    Q_PROPERTY(bool canEraseData READ canEraseData NOTIFY canEraseDataChanged)
+
+    /**
+     * @brief Whether this build of NeoChat supports push notifications via KUnifiedPush.
+     */
+    Q_PROPERTY(bool pushNotificationsAvailable READ pushNotificationsAvailable CONSTANT)
+
+    /**
+     * @brief Whether we successfully set up push notifications with the server.
+     */
+    Q_PROPERTY(bool enablePushNotifications READ enablePushNotifications NOTIFY enablePushNotificationsChanged)
+
 public:
     /**
      * @brief Defines the status after an attempt to change the password on an account.
@@ -104,6 +122,7 @@ public:
     Q_INVOKABLE void logout(bool serverSideLogout);
     Q_INVOKABLE QVariantList getSupportedRoomVersions() const;
     bool canCheckMutualRooms() const;
+    bool canEraseData() const;
 
     /**
      * @brief Change the password for an account.
@@ -123,7 +142,7 @@ public:
     [[nodiscard]] QString label() const;
     void setLabel(const QString &label);
 
-    Q_INVOKABLE void deactivateAccount(const QString &password);
+    Q_INVOKABLE void deactivateAccount(const QString &password, bool erase);
 
     ThreePIdModel *threePIdModel() const;
 
@@ -168,20 +187,24 @@ public:
     int badgeNotificationCount() const;
     void refreshBadgeNotificationCount();
 
+    bool globalUrlPreviewEnabled();
+    void setGlobalUrlPreviewEnabled(bool newState);
+
     bool directChatInvites() const;
 
     // note: this is intentionally a copied QString because
     // the reference could be destroyed before the task is finished
     QCoro::Task<void> setupPushNotifications(QString endpoint);
 
-    QString deviceKey() const;
-    QString encryptionKey() const;
+    bool pushNotificationsAvailable() const;
+    bool enablePushNotifications() const;
 
     bool isOnline() const;
 
     LinkPreviewer *previewerForLink(const QUrl &link);
 
 Q_SIGNALS:
+    void globalUrlPreviewEnabledChanged();
     void labelChanged();
     void identityServerChanged();
     void directChatNotificationsChanged();
@@ -194,6 +217,8 @@ Q_SIGNALS:
     void userConsentRequired(QUrl url);
     void badgeNotificationCountChanged(NeoChatConnection *connection, int count);
     void canCheckMutualRoomsChanged();
+    void canEraseDataChanged();
+    void enablePushNotificationsChanged();
 
     /**
      * @brief Request a message be shown to the user of the given type.
@@ -214,8 +239,11 @@ private:
     void connectSignals();
 
     int m_badgeNotificationCount = 0;
+    bool m_globalUrlPreviewEnabled = true;
 
     QCache<QUrl, LinkPreviewer> m_linkPreviewers;
 
     bool m_canCheckMutualRooms = false;
+    bool m_canEraseData = false;
+    bool m_pushNotificationsEnabled = false;
 };
