@@ -4,12 +4,15 @@
 #include "threepidaddhelper.h"
 
 #include <Quotient/converters.h>
+#include <Quotient/csapi/administrative_contact.h>
 #include <Quotient/csapi/definitions/auth_data.h>
 #include <Quotient/csapi/definitions/request_msisdn_validation.h>
 
-#include "jobs/neochatadd3pidjob.h"
 #include "neochatconnection.h"
 
+using namespace Qt::StringLiterals;
+using namespace Quotient;
+
 ThreePIdAddHelper::ThreePIdAddHelper(QObject *parent)
     : QObject(parent)
 {
@@ -86,7 +89,7 @@ void ThreePIdAddHelper::initiateNewIdAdd()
     if (m_newId.isEmpty()) {
         return;
     }
-    if (m_medium == QLatin1String("email")) {
+    if (m_medium == u"email"_s) {
         emailTokenJob();
     } else {
         msisdnTokenJob();
@@ -121,7 +124,7 @@ void ThreePIdAddHelper::msisdnTokenJob()
 void ThreePIdAddHelper::tokenJobFinished(Quotient::BaseJob *job)
 {
     if (job->status() == Quotient::BaseJob::Success) {
-        m_newIdSid = job->jsonData()[QLatin1String("sid")].toString();
+        m_newIdSid = job->jsonData()["sid"_L1].toString();
         m_newIdStatus = Verification;
         Q_EMIT newIdStatusChanged();
         return;
@@ -137,20 +140,19 @@ ThreePIdAddHelper::ThreePIdStatus ThreePIdAddHelper::newIdStatus() const
 
 void ThreePIdAddHelper::finalizeNewIdAdd(const QString &password)
 {
-    const auto job = m_connection->callApi<NeochatAdd3PIdJob>(m_newIdSecret, m_newIdSid);
+    const auto job = m_connection->callApi<Add3PIDJob>(m_newIdSecret, m_newIdSid);
     connect(job, &Quotient::BaseJob::result, this, [this, job, password] {
         m_newIdStatus = Authentication;
         Q_EMIT newIdStatusChanged();
 
         if (static_cast<Quotient::BaseJob::StatusCode>(job->error()) == Quotient::BaseJob::Unauthorised) {
             QJsonObject replyData = job->jsonData();
-            QJsonObject authData;
-            authData[QLatin1String("session")] = replyData[QLatin1String("session")];
-            authData[QLatin1String("password")] = password;
-            authData[QLatin1String("type")] = QLatin1String("m.login.password");
-            QJsonObject identifier = {{QLatin1String("type"), QLatin1String("m.id.user")}, {QLatin1String("user"), m_connection->userId()}};
-            authData[QLatin1String("identifier")] = identifier;
-            const auto innerJob = m_connection->callApi<NeochatAdd3PIdJob>(m_newIdSecret, m_newIdSid, authData);
+            AuthenticationData authData;
+            authData.session = replyData["session"_L1].toString();
+            authData.authInfo["password"_L1] = password;
+            authData.type = "m.login.password"_L1;
+            authData.authInfo["identifier"_L1] = QJsonObject{{"type"_L1, "m.id.user"_L1}, {"user"_L1, m_connection->userId()}};
+            const auto innerJob = m_connection->callApi<Add3PIDJob>(m_newIdSecret, m_newIdSid, authData);
             connect(innerJob, &Quotient::BaseJob::success, this, [this]() {
                 m_connection->threePIdModel()->refreshModel();
                 m_newIdSecret.clear();
@@ -159,10 +161,10 @@ void ThreePIdAddHelper::finalizeNewIdAdd(const QString &password)
                 Q_EMIT newIdStatusChanged();
             });
             connect(innerJob, &Quotient::BaseJob::failure, this, [innerJob, this]() {
-                if (innerJob->jsonData()[QLatin1String("errcode")] == QLatin1String("M_FORBIDDEN")) {
+                if (innerJob->jsonData()["errcode"_L1] == "M_FORBIDDEN"_L1) {
                     m_newIdStatus = AuthFailure;
                     Q_EMIT newIdStatusChanged();
-                } else if (innerJob->jsonData()[QLatin1String("errcode")] == QLatin1String("M_THREEPID_AUTH_FAILED")) {
+                } else if (innerJob->jsonData()["errcode"_L1] == "M_THREEPID_AUTH_FAILED"_L1) {
                     m_newIdStatus = VerificationFailure;
                     Q_EMIT newIdStatusChanged();
                 } else {
